#[repr(i32)]pub enum CalendarPeriod {
Unspecified = 0,
Day = 1,
Week = 2,
Fortnight = 3,
Month = 4,
Quarter = 5,
Half = 6,
Year = 7,
}Expand description
A CalendarPeriod represents the abstract concept of a time period that has
a canonical start. Grammatically, “the start of the current
CalendarPeriod.” All calendar times begin at midnight UTC.
Variants
Unspecified = 0
Undefined period, raises an error.
Day = 1
A day.
Week = 2
A week. Weeks begin on Monday, following ISO 8601.
Fortnight = 3
A fortnight. The first calendar fortnight of the year begins at the start of week 1 according to ISO 8601.
Month = 4
A month.
Quarter = 5
A quarter. Quarters start on dates 1-Jan, 1-Apr, 1-Jul, and 1-Oct of each year.
Half = 6
A half-year. Half-years start on dates 1-Jan and 1-Jul.
Year = 7
A year.
Implementations
Sourceimpl CalendarPeriod
impl CalendarPeriod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<CalendarPeriod>
pub fn from_str_name(value: &str) -> Option<CalendarPeriod>
Creates an enum from field names used in the ProtoBuf definition.
Sourceimpl CalendarPeriod
impl CalendarPeriod
Sourcepub fn is_unspecified(&self) -> bool
pub fn is_unspecified(&self) -> bool
Checks if the value is of the unspecified variant.
Sourcepub fn is_fortnight(&self) -> bool
pub fn is_fortnight(&self) -> bool
Checks if the calendar period is a fortnight.
Sourcepub fn is_quarter(&self) -> bool
pub fn is_quarter(&self) -> bool
Checks if the calendar period is a quarter.