LessThan

Enum LessThan 

pub enum LessThan {
    Lt(u32),
    Lte(u32),
}
Available on crate feature protovalidate only.

Variants



Lt(u32)

lt requires the field value to be less than the specified value (field < value). If the field value is equal to or greater than the specified value, an error message is generated.

message MyFixed32 {
   // value must be less than 10
   fixed32 value = 1 \[(buf.validate.field).fixed32.lt = 10\];
}


Lte(u32)

lte requires the field value to be less than or equal to the specified value (field <= value). If the field value is greater than the specified value, an error message is generated.

message MyFixed32 {
   // value must be less than or equal to 10
   fixed32 value = 1 \[(buf.validate.field).fixed32.lte = 10\];
}

Implementations

Source

impl LessThan

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<LessThan>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.